@@ -1361,7 +1361,7 @@ GEN hnfspec(long** mat, GEN* ptpdep, GEN* ptmatc,long* vperm,GEN* ptmatalpha,lon
       p1=cgetg(li+1,18);matgen[j]=(long)p1;
       for(i=1;i<=li;i++) p1[i]=lstoi(mat[j][vperm[i]]);
     }
-/*  output(matgen); */
+  if(DEBUGLEVEL>2) output(matgen);
   matu=cgetg(co+1,19);
   for(j=1;j<=co;j++)
     {
@@ -1399,7 +1399,7 @@ GEN hnfspec(long** mat, GEN* ptpdep, GEN* ptmatc,long* vperm,GEN* ptmatalpha,lon
       p1=cgetg(li-k0+1,18);matgen[j]=(long)p1;
       for(i=k0+1;i<=li;i++) p1[i]=lstoi(mat[j][vperm[i]]);
     }
-/*  output(matgen); */
+  if(DEBUGLEVEL>2) output(matgen);
   fl=1;sizemax=0;
   while((lig>lk0)&&fl&&(sizemax<=((long)MAXULONG>>2)))
     {
@@ -1462,7 +1462,7 @@ GEN hnfspec(long** mat, GEN* ptpdep, GEN* ptmatc,long* vperm,GEN* ptmatalpha,lon
       p1=cgetg(li-k0+1,18);matgen[j]=(long)p1;
       for(i=k0+1;i<=li;i++) p1[i]=lstoi(mat[j][vperm[i]]);
     }
-/*  output(matgen); */
+  if(DEBUGLEVEL>2) output(matgen);
   while((lig>lk0)&&fl)
     {
       for(i=lig;i>lk0;i--)
