@@ -1239,6 +1239,21 @@ int isfundamental(GEN x)
   return (r==1)?issquarefree(x):0;
 }
 
+GEN quaddisc(GEN x)
+{
+  long av=avma,tetpil,i,r,tx=typ(x);
+  GEN p1,p2,f,s;
+
+  if((tx!=1)&&(tx!=4)&&(tx!=5)) err(arither1);
+  f=factor(x);p1=(GEN)f[1];p2=(GEN)f[2];
+  s=gun;
+  for(i=1;i<lg(p1);i++)
+    if((((GEN)p2[i])[2])&1) {tetpil=avma;s=gmul(s,(GEN)p1[i]);}
+  r=s[lgef(s)-1]&3;if(signe(x)<0) r=4-r;
+  if(r>1) {tetpil=avma;s=shifti(s,2);}
+  return gerepile(av,tetpil,s);
+}
+
 /*********************************************************************/
 /*********************************************************************/
 /**                                                                 **/
