@@ -481,7 +481,8 @@ GEN    gscal(GEN x, GEN y)
   GEN  z,p;
   long i,av,tetpil,lx=lg(x);
   
-  z=gzero;av=avma;
+  z=gzero;if(lx==1) return z;
+  av=avma;
   for (i=1;i<lx;i++)
     {
       p=gmul((GEN)x[i],(GEN)y[i]);
@@ -1609,7 +1610,11 @@ GEN    lindep(GEN x, long prec)
         em=p3;j=i;
       }
     }
-    avma=av1;i=j;i1=i+1;
+    avma=av1;
+/*    printf("\n");
+    for(i1=1;i1<=n;i1++)
+      for(i=1;i<i1;i++) output(m[i1][i]); */
+    i=j;i1=i+1;
     r=ground(m[i1][i]);f=subri(m[i1][i],r);
     p3=gsub(b[i1],gmul(r,b[i]));
     b[i1]=b[i];b[i]=p3;
