@@ -55,8 +55,8 @@ GEN buchimag(GEN D, GEN gcbach, GEN gcbach2, GEN gCO)
 {
   long CO;
   double cbach,cbach2;
-  long limc,limc2,mglob,m,cp,nbram,auxrel,lo,lo1,ran,nlze,col;
-  long *fpd,b1,b2,fpc,pp,ep,b,extrarel,c,ic,jc,limhash;
+  long limc,limc2,mglob,m,cp,nbram,auxrel,lo,lo1,nlze,col;
+  long *fpd,b1,b2,fpc,pp,ep,b,extrarel,c,limhash;
   long kc2,*numbase,*base,*subbase;
   long **mat,**matinit,*vectprime,*vperm,*vinvperm;
   long primfact[100],expoprimfact[100],primfact1[100],expoprimfact1[100];
@@ -64,8 +64,8 @@ GEN buchimag(GEN D, GEN gcbach, GEN gcbach2, GEN gCO)
   long av=avma,tetpil,kc,kcco,kccopro,i,j,*pro,p2,*p1,*ex,q,s,nbtest,mm,av3;
   long sizeofmit,k,nrelsup,nreldep;
   double drc,lim,logd;
-  GEN dr,v,detmat,u1u2,u1,u2,c_1;
-  GEN matgen,matc,matalpha,**vp,form,form1,pc,mit,met,mot,p3,p4,basecl;
+  GEN dr,v,u1u2,u1,u2,c_1;
+  GEN matc,matalpha,**vp,form,form1,pc,mit,met,mot,p3,p4,basecl;
   GEN extramat,extramatc,pdep;
   long* hashtab[HASHT];
 
@@ -117,8 +117,8 @@ GEN buchimag(GEN D, GEN gcbach, GEN gcbach2, GEN gCO)
   kcco=kc+CO;
   mglob=m=subbase[0];
   vp=powsubfactimag(v,m,CBUCH+7);
-  mat=(long **)malloc(sizeof(long)*(kcco+1));
-  matinit=(long **)malloc(sizeof(long)*(kcco+1));
+  mat=(long **)malloc(sizeof(long*)*(kcco+1));
+  matinit=(long **)malloc(sizeof(long*)*(kcco+1));
   for(i=1;i<=kcco;i++)
     {
       p1=(long *)malloc(sizeof(long)*(kc+1));matinit[i]=mat[i]=p1;
@@ -128,7 +128,7 @@ GEN buchimag(GEN D, GEN gcbach, GEN gcbach2, GEN gCO)
   q=BITS_IN_LONG-1-(long)ceil(log((double)CBUCH)/log(2.0));
   s=0;nbtest=0;
   mm=m+nbram+CO;
-  limhash=(limc<(MAXHALFULONG>>1))?limc*limc:((ulong)(HIGHBIT>>1));
+  limhash=(limc<(MAXHALFULONG>>1))?limc*limc:((ulong)(HIGHBIT)>>1);
   for(i=0;i<HASHT;i++) hashtab[i]=(long*)0;
   auxrel=0;
   while(s<mm)
@@ -471,8 +471,8 @@ GEN **powsubfactimag(GEN w, long n, long a)
   long i,j;
   GEN **x;
 
-  x=(GEN**)malloc(sizeof(long)*(n+1));
-  for(i=1;i<=n;i++) x[i]=(GEN*)malloc(sizeof(long)*(a+1));
+  x=(GEN**)malloc(sizeof(GEN*)*(n+1));
+  for(i=1;i<=n;i++) x[i]=(GEN*)malloc(sizeof(GEN)*(a+1));
   for(i=1;i<=n;i++)
     {
       x[i][0]=gpuigs((GEN)w[1],0);
@@ -578,18 +578,18 @@ GEN buchreal(GEN D, GEN gsens, GEN gcbach, GEN gcbach2, GEN gRELSUP, long prec)
   long sens,RELSUP,nrelsup,nreldep,kccopro;
   double cbach,cbach2;
   long precreg,limc,limbach,cardsubbase,cardsub,nbram,auxrel;
-  long nbprimfact,nbprimfact1,ran,fl,fl2,lo,initform5,findecycle,memoirefindecycle;
-  long nbrhocourant,nbrhocumule,nrho,*fpd,b1,b2,fpc,pp,ep,b,extrarel,c,ic,jc,limhash;
-  long sizebach,nbcol1,nbcol2,nbcol3,nbrow1,nbrow2,nbrow3,*numbase,*base,*subbase;
+  long nbprimfact,nbprimfact1,fl,fl2,lo,initform5,findecycle,memoirefindecycle;
+  long nbrhocourant,nbrhocumule,nrho,*fpd,b1,b2,fpc,pp,ep,b,extrarel,c,limhash;
+  long sizebach,*numbase,*base,*subbase;
   long **mat,**matinit,*vectprime,*vperm,*vinvperm;
   long primfact[100],expoprimfact[100],primfact1[100],expoprimfact1[100];
   long badprim[100],nbbadprim,nlze,col,sizeofmit;
   long av=avma,av1,av2,tetpil,dec,sizemat,sizematcol,i,j,k,*pro,p2,*p1,*ex,qqq,s,nbtest,mm;
   double drc,lim,logd;
-  GEN dr,sqrtD,isqrtD,log2precis,tabprform,detmat,detmatsur2;
-  GEN matgen,matc,extramat,extramatc,vecexpo,**tabpowprform;
+  GEN dr,sqrtD,isqrtD,log2precis,tabprform;
+  GEN matc,extramat,extramatc,**tabpowprform;
   GEN forminit,form,form0,form1,form2,pc,mit,met,mot,p3,p4,pdep,matalpha;
-  GEN wecexpo,xecexpo,matpro;
+  GEN vecexpo;
   GEN reg,c_1,u1u2,u1,u2,basecl;
   long* hashtab[HASHT];
 
@@ -599,7 +599,7 @@ GEN buchreal(GEN D, GEN gsens, GEN gcbach, GEN gcbach2, GEN gRELSUP, long prec)
   s=D[lgef(D)-1]&3;
   if((s==2)||(s==3)) err(bucher4);
   if(signe(gRELSUP)<=0) err(bucher5);
-  sens=abs(signe(gsens));
+  sens=labs(signe(gsens));
   if(sens) 
     {
       /* sens=0;fprintf(stderr,"\n  ***   Warning: narrow class group request not yet implemented, ignored\n"); */
@@ -638,8 +638,8 @@ increasereal:
   tabpowprform=powsubfactreal(tabprform,cardsub,CBUCH+7,D,isqrtD,sqrtD,sens,precreg);
   vecexpo=cgetg(sizematcol+1,17);
   for(i=1;i<=sizematcol;i++) vecexpo[i]=lgetr(precreg);
-  mat=(long**)malloc((sizematcol+1)*sizeof(long));if(!((long)mat)) err(talker,"out of memory6!");
-  matinit=(long**)malloc((sizematcol+1)*sizeof(long));if(!((long)matinit)) err(talker,"out of memory7!");
+  mat=(long**)malloc((sizematcol+1)*sizeof(long*));if(!((long)mat)) err(talker,"out of memory6!");
+  matinit=(long**)malloc((sizematcol+1)*sizeof(long*));if(!((long)matinit)) err(talker,"out of memory7!");
   for(i=1;i<=sizematcol;i++)
     {
       matinit[i]=mat[i]=(long*)malloc((sizemat+1)*sizeof(long));
@@ -1051,10 +1051,10 @@ GEN **powsubfactreal(GEN w, long n, long a, GEN D, GEN isqrtD, GEN sqrtD, long s
   long i,j;
   GEN **x;
 
-  if(!(x=(GEN**)malloc(sizeof(long)*(n+1)))) err(talker,"out of memory13!");
+  if(!(x=(GEN**)malloc(sizeof(GEN*)*(n+1)))) err(talker,"out of memory13!");
   for(i=1;i<=n;i++) 
     {
-      if(!(x[i]=(GEN*)malloc(sizeof(long)*(a+1)))) err(talker,"out of memory14!");
+      if(!(x[i]=(GEN*)malloc(sizeof(GEN)*(a+1)))) err(talker,"out of memory14!");
     }
   for(i=1;i<=n;i++)
     {
@@ -1443,24 +1443,22 @@ GEN lfunc(GEN D)
 
 GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
 {
-  long i,j,k,l,ii,ee,nn,ss,lgsub,n1,cp,av=avma,av0,tetpil,*p1,*ex,q,s,nbtest,av3;
-  long N,R1,R2,RU,CO,PRECREG,LIMC,LIMC2,lim,blim,KC,KC2,KCZ,KCZ2,KCCO,KCCOPRO;
-  long ip,nbcol3,nbrow3,ran,c,ic,jc,lo,extrarel,iz,pz,ncz;
-  long col,k0,nlze,sizeofmit,sreg,ep,colnew;
+  long i,j,k,ss,lgsub,n1,cp,av=avma,av0,tetpil,*p1,*ex,q,s,nbtest,av3;
+  long N,R1,R2,RU,CO,PRECREG,LIMC,LIMC2,lim,KC,KC2,KCZ,KCZ2,KCCO,KCCOPRO;
+  long ip,c,lo,extrarel,iz,pz,ncz;
+  long col,mitcol,k0,nlze,sizeofmit,sreg,ep,colnew;
   long **mat,**matinit,*vperm,*vinvperm;
-  long limhash=0,fpc,mitcol,mitlin;
+  long limhash=0,fpc;
   long expoprimfact[500],primfact[500],*numprim,*prim,*numideal,nrelsup,nreldep;
   double cbach,cbach2,drc,mr,LOGD;
-  GEN pgen1,pgen2,pgen3,pgen4,pgen5,dr,ideal,**vp,*idealbase,matarch,exu,fu,zu;
+  GEN pgen1,pgen2,pgen3,dr,ideal,**vp,*idealbase,matarch,exu,fu,zu;
   GEN nf,D,F,BINV,primsubfactorbase,vectbase;
-  GEN matgen,matpro,xarch,xreal,vei,p3,met,mot,mit,detmat,reg,mdet,lfun,z,clh;
+  GEN xarch,xreal,vei,p3,met,mot,mit,reg,mdet,lfun,z,clh;
   GEN matalpha,u1u2,u1,u2,RES,basecl,extramat,extramatc;
-  GEN lambda,sublambda_1,c_1,den,matunit,image_mdet,pdep;
+  GEN lambda,sublambda_1,c_1,den,image_mdet,pdep;
 
 
-#ifdef DEBUG
-  gettime();
-#endif
+  if(DEBUGLEVEL) gettime();
   if(abs(flun)>1) RES=cgetg(11,17);
   else RES=flun?cgetg(9,17):cgetg(8,17);
   if(typ(gRELSUP)!=1) gRELSUP=gtrunc(gRELSUP);
@@ -1495,13 +1493,9 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
     }
   pgen1=factor(P);pgen2=(GEN)pgen1[1];pgen3=(GEN)pgen1[2];
   if((lg(pgen2)>2)||(cmpis((GEN)pgen3[1],1)>0)) err(bucher10);
-#ifdef DEBUG
-  printf("temps trivialites: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps trivialites: ");output(gettime());}
   nf=initalg0(P,max(8,prec));
-#ifdef DEBUG
-  printf("temps initalg0: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps initalg0: ");output(gettime());}
   RES[1]=nf[1];RES[2]=nf[2];pgen1=cgetg(3,17);RES[3]=(long)pgen1;pgen1[1]=nf[3];pgen1[2]=nf[4];
   R1=itos((GEN)((GEN)nf[2])[1]);R2=(N-R1)/2;RU=R1+R2;
   F=(GEN)nf[4];D=(GEN)nf[3];RES[4]=nf[7];
@@ -1520,13 +1514,9 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
   if(cp>LIMC) LIMC=cp;
   LIMC2=max(10*N,(long)(cbach2*LOGD*LOGD));
   if(LIMC>LIMC2) LIMC2=LIMC;
-#ifdef DEBUG
-  printf("temps rootsof1 et/ou trivialites: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps rootsof1 et/ou trivialites: ");output(gettime());}
   KC2=factorbasegen(nf,LIMC2,LIMC,&numprim,&prim,&numideal,&idealbase,&KC,&KCZ,&KCZ2,&lfun);
-#ifdef DEBUG
-  printf("temps creation de la factor base: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps creation de la factor base: ");output(gettime());}
   if(!KC)
     {
       if(cbach>11.99) 
@@ -1541,13 +1531,9 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
       for(j=1;j<n1;j++) vectbase[ip+j]=pgen1[j];
     }
   vperm=(long*)malloc(sizeof(long)*(KC+1));for(i=1;i<=KC;i++) vperm[i]=i;
-#ifdef DEBUG
-  printf("temps creation vperm et vectbase: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps creation vperm et vectbase: ");output(gettime());}
   primsubfactorbase=subfactorbasegen(N,min(lim,LIMC2),vectbase,vperm,&ss);
-#ifdef DEBUG
-  printf("temps creation de la sous-factor base: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps creation de la sous-factor base: ");output(gettime());}
   if(ss==-1) 
     {
       free(vperm);
@@ -1557,15 +1543,11 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
     }
   lgsub=lg(primsubfactorbase);
   vp=powsubfactgen(nf,primsubfactorbase,CBUCH+1,PRECREG);
-#ifdef DEBUG
-  printf("temps powsubfactgen: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps powsubfactgen: ");output(gettime());}
   KCCO=KC+max(CO,ss);
-#ifdef DEBUG
-  printf("KC = %ld, KCCO = %ld, lgsub = %ld\n",KC,KCCO,lgsub-1);fflush(stdout);
-#endif
-  mat=(long **)malloc(sizeof(long)*(KCCO+1));
-  matinit=(long **)malloc(sizeof(long)*(KCCO+1));
+  if(DEBUGLEVEL) {printf("KC = %ld, KCCO = %ld, lgsub = %ld\n",KC,KCCO,lgsub-1);fflush(stdout);}
+  mat=(long**)malloc(sizeof(long*)*(KCCO+1));
+  matinit=(long**)malloc(sizeof(long*)*(KCCO+1));
   matarch=cgetg(KCCO+1,19);
   for(i=1;i<=KCCO;i++)
     {
@@ -1593,17 +1575,19 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
 	}
     }
   nbtest=ss=s;
-#ifdef DEBUG
-  printf("temps creation mat et matarch: ");output(gettime());
-  printf("Apres relations triviales, s = nbtest = %ld\n",s);fflush(stdout);
-#endif
+  if(DEBUGLEVEL)
+    {
+      printf("temps creation mat et matarch: ");output(gettime());
+      printf("Apres relations triviales, s = nbtest = %ld\n",s);fflush(stdout);
+    }
 /*
   pgen1=minimprim((GEN)((GEN)nf[5])[3],(long)(N*pow(4.*((double)LIMC)*LIMC,(double)(4./N))),1000);
   k=itos((GEN)pgen1[1])>>1;pgen1=(GEN)pgen1[3];
-#ifdef DEBUG
-  printf("temps minimprim: ");output(gettime());
-  printf("place de stockage prevue dans minim = 1000, nombre trouve = %ld\n",k);fflush(stdout);
-#endif
+  if(DEBUGLEVEL)
+    {
+      printf("temps minimprim: ");output(gettime());
+      printf("place de stockage prevue dans minim = 1000, nombre trouve = %ld\n",k);fflush(stdout);
+    }
   pgen1=vecsort(pgen1,gun);
   pgen3=idmat(N);
   for(k=1;(s<KCCO)&&(k<lg(pgen1));k++)
@@ -1632,10 +1616,11 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
 	}
       avma=av3;
     }
-#ifdef DEBUG
-  printf("temps relations de petite norme: ");output(gettime());
-  printf("Apres relations de petite norme, s/nbtest = %ld/%ld\n",s,nbtest);fflush(stdout);
-#endif
+  if(DEBUGLEVEL)
+    {
+      printf("temps relations de petite norme: ");output(gettime());
+      printf("Apres relations de petite norme, s/nbtest = %ld/%ld\n",s,nbtest);fflush(stdout);
+    }
 */
   pgen2=cgetg(2,17);pgen2[1]=(long)vp[1][0];
   for(iz=1;s<KCCO;iz++)
@@ -1649,10 +1634,11 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
 	  for (i=1;i<lgsub;i++) ideal=idealmulh(nf,ideal,(GEN)vp[i][ex[i]]);
 	  for(i=1;i<=RU;i++) exu[i]=lstoi((mymyrand()>>q)+1);
 	  ideal=ideallllred(nf,ideal,exu,PRECREG);
-#ifdef DEBUG
-	  printf("s = %ld, nbtest = %ld, ideal = ",s,nbtest);
-	  output((GEN)ideal[1]);
-#endif
+	  if(DEBUGLEVEL)
+	    {
+	      printf("s = %ld, nbtest = %ld, ideal = ",s,nbtest);
+	      output((GEN)ideal[1]);
+	    }
 	  fpc=factorisegen(nf,(GEN)ideal[1],KCZ,LIMC,primfact,expoprimfact,prim,idealbase,numideal,numprim,limhash);
 	  nbtest++;
 	  if (fpc&&(s<KCCO))
@@ -1667,15 +1653,17 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
 	  avma=av3;
 	}
     }
-#ifdef DEBUG
-  printf("temps pour trouver les relations aleatoires: ");output(gettime());
-  printf("nbrelations/nbtest = %ld/%ld\n",s,nbtest);fflush(stdout);
-#endif
+  if(DEBUGLEVEL)
+    {
+      printf("temps pour trouver les relations aleatoires: ");output(gettime());
+      printf("nbrelations/nbtest = %ld/%ld\n",s,nbtest);fflush(stdout);
+    }
   k0=lgsub-1;
   mit=hnfspec(mat,&pdep,&matarch,vperm,&matalpha,KCCO,KC,k0,&nlze,&col);
-#ifdef DEBUG
-  printf("temps hnfspec: ");output(gettime());
-#endif
+  if(DEBUGLEVEL)
+    {
+      printf("temps hnfspec: ");output(gettime());
+    }
   mitcol=lg(mit)-1;
   KCCOPRO=KCCO;
  morerelgen:
@@ -1723,14 +1711,13 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
 	      for(i=1;i<=RU;i++) gaffect((GEN)((GEN)ideal[2])[i],(GEN)((GEN)extramatc[s])[i]);
 	    }
 	}
-#ifdef DEBUG
-      printf("temps calcul relations supplementaires: ");output(gettime());
-#endif
+      if(DEBUGLEVEL)
+	{
+	  printf("temps calcul relations supplementaires: ");output(gettime());
+	}
       if(nrelsup) nlze=0;
       mit=hnfadd(mit,&pdep,&matarch,vperm,&matalpha,KCCOPRO,KC,col,&nlze,extramat,extramatc);
-#ifdef DEBUG
-  printf("temps hnfadd: ");output(gettime());
-#endif
+      if(DEBUGLEVEL) {printf("temps hnfadd: ");output(gettime());}
       free(vinvperm);KCCOPRO+=extrarel;col=KCCOPRO-(lg(matalpha)-1);
       if(nlze)
 	{
@@ -1758,17 +1745,12 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
   vei=cgetg(RU+1,18);for(i=1;i<=RU;i++) vei[i]=(i<=R1)?un:deux;
   mdet=cgetg(sreg+2,19);for(j=2;j<=sreg+1;j++) mdet[j]=xreal[j-1];
   mdet[1]=(long)vei;
-#ifdef DEBUG
-  printf("temps trivialites xarch, xreal, mdet: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps trivialites xarch, xreal, mdet: ");output(gettime());}
   image_mdet=imagereel(mdet,PRECREG);
-#ifdef DEBUG
-  printf("temps imagereel: ");output(gettime());
-#endif
-  reg=gdivgs(gabs(detreel(image_mdet),PRECREG),N);
-#ifdef DEBUG
-  printf("temps detreel: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps imagereel: ");output(gettime());}
+  if(lg(image_mdet)!=(RU+1)) affsr(0,reg=cgetr(PRECREG));
+  else reg=gdivgs(gabs(detreel(image_mdet),PRECREG),N);
+  if(DEBUGLEVEL) {printf("temps detreel: ");output(gettime());}
   if(gexpo(reg)<=-4)
     {
       nrelsup++;
@@ -1795,9 +1777,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
       pgen1=cgetg(RU,18);sublambda_1[i]=(long)pgen1;pgen2=(GEN)lambda[i];
       for(j=1;j<RU;j++) pgen1[j]=pgen2[j+1];
     }
-#ifdef DEBUG
-  printf("temps trivialites lambda: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps trivialites lambda: ");output(gettime());}
   if(sizeofmit)
     {
       pgen1=gun;
@@ -1807,9 +1787,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
       met=gmul(u1,gmul(mit,u2));u1=ginv(u1);
     }
   else {clh=gun;met=cgetg(1,19);u1=cgetg(1,19);}
-#ifdef DEBUG
-  printf("temps smith/groupe de classes: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps smith/groupe de classes: ");output(gettime());}
   c_1=gmul2n(gdiv(reg,gdiv(gmul(z,(GEN)zu[1]),clh)),1);
   sublambda_1=bestappr(sublambda_1,c_1);
   den=denom(sublambda_1);
@@ -1817,9 +1795,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
   pgen1=(GEN)lllkerim(gmul(sublambda_1,den))[2];
   reg=gabs(gmul(reg,det(gmul(sublambda_1,pgen1))),PRECREG);
   c_1=gmul2n(gdiv(reg,gdiv(gmul(z,(GEN)zu[1]),clh)),1);
-#ifdef DEBUG
-  printf("temps bestappr/regulateur: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps bestappr/regulateur: ");output(gettime());}
   if(gcmpgs(gmul2n(c_1,1),3)<0) err(talker,"bug check in buchgen, PLEASE REPORT!!!");
   if(gcmpgs(c_1,3)>0) 
     {
@@ -1843,9 +1819,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
   xarch=cleancol(gmul(xarch,pgen1),N,RU,PRECREG);
   lo=lg(met)-1;
   c=0;for(i=1;i<=lo;i++) if(!gcmp1(gcoeff(met,i,i))) c++;
-#ifdef DEBUG
-  printf("temps trivialites cleancol: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps trivialites cleancol: ");output(gettime());}
   basecl=cgetg(c+1,17);
   for(j=1;j<=c;j++)
     {
@@ -1868,9 +1842,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
   mot=cgetg(c+1,17);for(i=1;i<=c;i++) mot[i]=coeff(met,i,i);
   pgen1=cgetg(4,17);RES[5]=(long)pgen1;pgen1[1]=(long)clh;pgen1[2]=(long)mot;
   pgen1[3]=(long)basecl;
-#ifdef DEBUG
-  printf("temps generateurs du groupe de classes: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps generateurs du groupe de classes: ");output(gettime());}
   RES[6]=(long)reg;
   z=gdiv(gmul(reg,clh),gmul((GEN)zu[1],z));
   RES[7]=(long)z;
@@ -1895,9 +1867,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
       else c=0;
       RES[9]=c?lmul((GEN)nf[7],fu):(long)fu;
       RES[10]=lstoi(c);
-#ifdef DEBUG
-      printf("temps getfu: ");output(gettime());
-#endif
+      if(DEBUGLEVEL) {printf("temps getfu: ");output(gettime());}
     }
   tetpil=avma;
   if(flun>=0) {z=cgetg(2,19);z[1]=lcopy(RES);}
@@ -1920,9 +1890,7 @@ GEN buchall(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long flun, long prec)
   free(ex);for(i=1;i<=KCCO;i++) free(matinit[i]);free(matinit);free(mat);
   free(vperm);
   return gerepile(av,tetpil,z);
-#ifdef DEBUG
-  printf("temps free finaux: ");output(gettime());
-#endif
+  if(DEBUGLEVEL) {printf("temps free finaux: ");output(gettime());}
 }
 
 GEN buchgen(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long prec)
@@ -1949,7 +1917,7 @@ GEN buchinitfu(GEN P, GEN gcbach, GEN gcbach2, GEN gRELSUP, long prec)
 
 GEN subfactorbasegen(long N, long m, GEN vectbase, long *vperm, long* ptss)
 {
-  long av=avma,tetpil,i,j,k,l,s,s1,s2,e,nbidp,ss=0;
+  long av=avma,tetpil,i,j,k,s,s1,s2,e,nbidp,ss=0;
   GEN y,y1,y2,y3,p1,perm,perm1;
   double prod;
 
@@ -2000,8 +1968,8 @@ GEN **powsubfactgen(GEN nf, GEN w, long a, long PRECREG)
   GEN **x,pgen1,id;
 
   R1=itos((GEN)((GEN)nf[2])[1]);R2=(N-R1)/2;RU=R1+R2;
-  x=(GEN**)malloc(sizeof(long)*(n+1));
-  for(i=1;i<=n;i++) x[i]=(GEN*)malloc(sizeof(long)*(a+1));
+  x=(GEN**)malloc(sizeof(GEN*)*(n+1));
+  for(i=1;i<=n;i++) x[i]=(GEN*)malloc(sizeof(GEN)*(a+1));
   id=cgetg(3,17);id[1]=(long)idmat(N);pgen1=cgetg(RU+1,17);
   id[2]=(long)pgen1;for(i=1;i<=RU;i++) pgen1[i]=zero;
   for(i=1;i<=n;i++) 
@@ -2019,8 +1987,8 @@ GEN **newpowsubfactgen(GEN nf, GEN w, long a, long PRECREG)
   GEN **x,pgen1,pgen2,pgen3,pgen4,pgen5,pgen6,id;
 
   R1=itos((GEN)((GEN)nf[2])[1]);R2=(N-R1)/2;RU=R1+R2;
-  x=(GEN**)malloc(sizeof(long)*(n+1));
-  for(i=1;i<=n;i++) x[i]=(GEN*)malloc(sizeof(long)*(a+1));
+  x=(GEN**)malloc(sizeof(GEN*)*(n+1));
+  for(i=1;i<=n;i++) x[i]=(GEN*)malloc(sizeof(GEN)*(a+1));
   id=cgetg(3,17);id[1]=(long)idmat(N);pgen1=cgetg(RU+1,17);
   id[2]=(long)pgen1;for(i=1;i<=RU;i++) pgen1[i]=zero;
   for(i=1;i<=n;i++) 
@@ -2070,7 +2038,7 @@ long factorbasegen(GEN nf, long n2, long n, long **ptnumprim, long **ptprim, lon
   numprimfactorbase=(long*)malloc(sizeof(long)*(n2+1));
   primfactorbase=(long*)malloc(sizeof(long)*(n2+1));
   numideal=(long*)malloc(sizeof(long)*(n2+1));
-  idealbase=(GEN*)malloc(sizeof(long)*(n2+1));
+  idealbase=(GEN*)malloc(sizeof(GEN)*(n2+1));
   lfun=cgetr(5);affsr(1,lfun);*ptlfun=lfun;
   i=0;pp=*delta++;fl=1;ip=0;*ptkc=0;
   while(pp<=n2)
@@ -2208,7 +2176,7 @@ GEN cleancol(GEN x,long N,long RU,long PRECREG)
 GEN getfu(GEN nf, GEN xarch, GEN reg, long *pte, long PRECREG)
 {
   long av=avma,av1,tetpil,i,j,RU,N=lgef((GEN)nf[1])-3,e,R1,R2;
-  GEN p1,p2,p3,y,rpro,rpro2,matep,s,u,v;
+  GEN p1,p2,p3,y,matep,s;
 
   R1=itos((GEN)((GEN)nf[2])[1]);R2=(N-R1)>>1;RU=R1+R2;
   if(RU==1) return cgetg(1,19);
@@ -2295,8 +2263,8 @@ GEN gcdrealnoer(GEN a, GEN b)
 
 long factorisegensimple(GEN nf, GEN ideal, long *primfact, long *expoprimfact, GEN vectbase)
 {
-  long sr,i,j,n1,ip,p,v,k,fl=1,av1,av2,q1,lo;
-  GEN x,q,r,p1;
+  long i,p,v,fl=1,av1,av2,lo;
+  GEN x,p1;
 
   av1=avma;lo=0;
   for(x=gun,i=1;i<lg(ideal);i++) x=mulii(x,gcoeff(ideal,i,i));
@@ -2322,9 +2290,9 @@ long factorisegensimple(GEN nf, GEN ideal, long *primfact, long *expoprimfact, G
 GEN isprincipal(GEN bignf, GEN x)
 {
   long expoprimfact[500],primfact[500],av=avma,tetpil,*vinvperm;
-  long i,j,fpc,fl,colmit,colnew,k,N,R1,R2,RU,e,pr,c,ss;
+  long i,j,fpc,colmit,colnew,k,N,R1,R2,RU,e,pr,c,ss;
   GEN xalpha,yalpha,mit,matalpha,matunit,matalphac,vectbase,vperm,nf,a,RES;
-  GEN u1u2,u1,u2,met,y,p1,p2,p3,p4,p5,s,s1,s2,om1,om2,om3,xar,pgen1,vdir;
+  GEN u1u2,u1,u2,y,p1,p2,p3,p4,p5,s,s1,s2,om1,om2,om3,xar,pgen1,vdir;
 
   if((typ(bignf)!=17)||(lg(bignf)!=9))
     err(talker,"not a big number field vector in isprincipal");
