@@ -2011,7 +2011,7 @@ GEN     gsqr(GEN x)
   else if(tx==16) y=sqcomp(x);
   else
   {
-    if((tx<17)||((tx==19)&&(lg(x)==lg((GEN)x[1])))) y=gmul(x,x);
+    if((tx<17)||((tx==19)&&((lg(x)==1)||(lg(x)==lg((GEN)x[1]))))) y=gmul(x,x);
     else
     {
       y=cgetg(lx=lg(x),tx);
