@@ -11,21 +11,19 @@
 
 #include "genpari.h"
 #include <readline/readline.h>
-#include <readline/history.h>
-
+/* #include <readline/history.h> */
 
 long    champ, dec, nbchi, avglob;
 extern  long avloc;
-long    prettyp = 1, chrono = 0;
+long    prettyp = 1, chrono = 0, simplifyflag = 1;
 char    prompt[79], format;
 
-#define NUMGLOB sizeof(globales)/4
+#define NUMGLOB sizeof(globales)/sizeof(char*)
   
   static char *globales[] = {"precision", "serieslength", "format", "prompt"};
 
 void escape(char *tch, long parisize, long primelimit);
 void commands(int n), menucommands(void), slashcommands(void), gentypes(void), aide(char *s), globs(long parisize, long primelimit);
-long timer(void);
 
 char* findsep(char **t)
 {
@@ -62,7 +60,7 @@ void usage(char *s)
 
 int main(long argc, char **argv)
 {
-  long  i,typy, parisize, primelimit, silent;
+  long  i,typy, parisize, primelimit, silent, avs, tets;
   static long tloc,listloc;
   char  *buffer, *tch, *tch2, thestring[100];
   GEN  z;
@@ -91,7 +89,7 @@ int main(long argc, char **argv)
   buffer = (char *)malloc(paribuffsize);
   
   avglob = avloc = avma;
-  tglobal=0;chrono=0;
+  tglobal=chrono=0;simplifyflag=1;
 #ifdef LONG_IS_64BIT
   prec=4;dec=38;nbchi=38;
 #else
@@ -207,7 +205,7 @@ int main(long argc, char **argv)
       fflush(outfile); if (logfile) fflush(logfile);
       if(!tglobal) timer2();
       if (chrono) timer();
-      z = readseq(&tch);
+      avs=avma;z = readseq(&tch);
       nbchi=dec=glbfmt[2];
       if (*tch) {pariputs("  unused characters: "); pariputs(tch); pariputc('\n');}
       if (chrono)
@@ -238,7 +236,16 @@ int main(long argc, char **argv)
 	  pariputs(thestring);
 	}
       if (z == gnil) continue;
-      g[0] = g[++tglobal] = isonstack(z) ? z : gcopy(z);
+      if(simplifyflag) 
+	{
+	  if(isonstack(z))
+	    {
+	      tets = avma;
+	      z = g[0] = g[++tglobal] = gerepile(avs,tets,simplify(z));
+	    }
+	  else {z = g[0] = g[++tglobal] = simplify(z);}
+	}
+      else {g[0] = g[++tglobal] = isonstack(z) ? z : gcopy(z);}
       typy=typ(z);
       if (!separe(*tch2))
 	{
@@ -287,12 +294,12 @@ void escape(char *tch, long parisize, long primelimit)
 	  {
 	  case 0: 
 	    glbfmt[2] = nbchi = dec = getint(s1, dec);
-	    prec = dec * K1 + 3;
+	    prec = (long)(dec*K1+3);
 	    sprintf(thestring, "   precision = %d significant digits\n",dec);
 	    pariputs(thestring);
 	    return;
 	  case 1:
-	    precdl = getint(s1);
+	    precdl = getint(s1, precdl);
 	    sprintf(thestring, "   series precision = %d significant terms\n",precdl);
 	    pariputs(thestring);
 	    return;
@@ -331,10 +338,15 @@ void escape(char *tch, long parisize, long primelimit)
     case 'c': checkok(tch); commands(-1); break;
     case 'd': checkok(tch); globs(parisize,primelimit); break;
     case 'e': checkok(tch); pariecho = !pariecho; break;
+    case 'g': while(isspace(*tch)) tch++;
+      for (d = 0; isdigit(*tch);) d = 10 * d + *tch++ - '0';
+      sprintf(thestring, "    debug level = %ld\n", d);DEBUGLEVEL = d;
+      pariputs(thestring);break;
     case 'k': checkok(tch);
       avma = avloc = avglob;
-      tglobal = chrono = 0;
+      tglobal = chrono = 0; simplifyflag = 1;
       gpi = geuler = bernzone = (GEN)0;
+      pari_randseed = 1; DEBUGLEVEL = 0;
 #ifdef LONG_IS_64BIT
       prec=4;dec=38;nbchi=38;
 #else
@@ -348,7 +360,7 @@ void escape(char *tch, long parisize, long primelimit)
       strcpy(prompt,"? ");
 #endif
       for (i = 0; i < STACKSIZE; i++) g[i] = gzero;
-      globs(parisize,primelimit);
+      globs(top-bot,primelimit);
       break;
     case 'l': checkok(tch); fliplog(); break;
     case 'm': matbrute(g[getint(tch, tglobal)], format, -1);pariputc('\n');
@@ -383,6 +395,8 @@ void escape(char *tch, long parisize, long primelimit)
       brute(g[d ? d : tglobal], format, -1);
       pariputc('\n'); switchout(NULL); break;
     case 'x': voir(g[tglobal], getint(tch, -1)); break;
+    case 'y': pariputs("    automatic simplification ");
+      pariputs((simplifyflag = !simplifyflag) ? "on\n" : "off\n"); break;
     case '\\': break;
     default: err(caracer1,tch+1);
     }
@@ -400,7 +414,7 @@ void gentypes(void)
 {
   pariputs("\n      List of the PARI types :");
   pariputs("\n     -------------------------\n\n");
-  pariputs("  1  :longegers     [ cod1 ] [ cod2 ] [ man1 ] ... [ manl ]\n");
+  pariputs("  1  :long integers     [ cod1 ] [ cod2 ] [ man1 ] ... [ manl ]\n");
   pariputs("  2  :long real numbers [ cod1 ] [ cod2 ] [ man1 ] ... [ manl ]\n");
   pariputs("  3  :integermods       [ code ] [ mod  ] [ integer ]\n");
   pariputs("  4  :irred. rationals  [ code ] [ num. ] [ den. ] \n");
@@ -476,6 +490,7 @@ void slashcommands(void)
   pariputs("\\c : list all commands (same effect as ?*)\n");
   pariputs("\\d : give current defaults and syntax to change them\n");
   pariputs("\\e : enable/disable echo\n");
+  pariputs("\\g : set debugging level\n");
   pariputs("\\k : kill current GP session but do not exit\n");
   pariputs("\\l : enable/disable logfile\n");
   pariputs("\\m : print result in prettymatrix format\n");
@@ -487,6 +502,7 @@ void slashcommands(void)
   pariputs("\\v : print current version of GP\n");
   pariputs("\\w : write to a file\n");
   pariputs("\\x : print complete inner structure of last result\n");
+  pariputs("\\y : disable/enable automatic simplification\n");
 }
 
 void globs(long parisize, long primelimit)
@@ -546,59 +562,9 @@ void aide(char *s)
 	    pariputs((*q++)->name);
 	  }
 	pariputs(")= ");
-	pariputs(q);
+	pariputs((char*)q);
 	return;
       }
   pariputs("Unknown function\n");
 }
 
-/********************************************************************/
-/********************************************************************/
-/**                                                                **/
-/**                       MESURE DU TEMPS                          **/
-/**                                                                **/
-/********************************************************************/
-/********************************************************************/
-
-#ifdef macintosh
-
-pascal unsigned long TickCount(void) = 0xA975;
-     
-long timer(void)
-{
-  static long oldticks;
-  long ticks = TickCount();
-  long delay = ticks - oldticks;
-  oldticks = ticks;
-  return 50 * delay / 3;
-}
-
-#else
-#ifdef hppa
-
-long timer(void)
-{
-  static ulong oldmusec;
-  ulong totalmusec = clock();
-  ulong delay = (totalmusec - oldmusec) / 1000;
-  oldmusec = totalmusec;
-  return delay;
-}
-#else
-
-long timer(void)
-{
-  static long oldmusec;
-  static long oldsec;
-  long delay;
-  struct rusage r;
-  struct timeval t;
-  getrusage(0,&r);t=r.ru_utime;
-  delay = 1000 * (t.tv_sec - oldsec) + (t.tv_usec - oldmusec) / 1000;
-  oldmusec = t.tv_usec;
-  oldsec = t.tv_sec;
-  return delay;
-}
-
-#endif
-#endif
