@@ -57,6 +57,7 @@ char *helpmessage[] =
   "coeff(x,s)=coefficient of degree s of x, or the s-th component for vectors\nor matrices (for which it is simpler to use x[])",
   "compimag(x,y)=Gaussian composition of the binary quadratic forms x and y\nof negative discriminant",
   "compo(x,s)=the s'th component of the internal representation of x.\nFor vectors or matrices, it is simpler to use x[]",
+  "compositum(pol1,pol2)=compositum of the number fields defined by the polynomials pol1\nand pol2",
   "comprealraw(x,y)=Gaussian composition without reduction of the binary quadratic\nforms x and y of positive discriminant",
   "concat(x,y)=concatenation of x and y",
   "conj(x)=the algebraic conjugate of x",
@@ -77,7 +78,8 @@ char *helpmessage[] =
   "detr(x)=determinant of the matrix x having real entries",
   "dilog(x)=dilogarithm of x",
   "disc(x)=discriminant of the polynomial x",
-  "discf(x)=discriminant of the number field defined by the polynomial x",
+  "discf(x)=discriminant of the number field defined by the polynomial x using round 4",
+  "discf2(x)=discriminant of the number field defined by the polynomial x using round 2",
   "divisors(x)=gives a vector formed by the divisors of x in increasing order",
   "divres(x,y)=euclidean division of x by y giving as a 2-dimensional column\nvector the quotient and the remainder",
   "divsum(n,X,expr)=sum of expression expr, X running over the divisors of n",
@@ -310,6 +312,7 @@ char *helpmessage[] =
   "psi(x)=psi-function at x",
   "qfi(a,b,c)=binary quadratic form a*x^2+b*x*y+c*y^2 with b^2-4*a*c<0",
   "qfr(a,b,c,d)=binary quadratic form a*x^2+b*x*y+c*y^2 with b^2-4*a*c>0 and\ndistance d",
+  "quaddisc(x)=discriminant of the quadratic field Q(sqrt(x))",
   "quadgen(x)=standard generator of quadratic order of discriminant x",
   "quadpoly(x)=quadratic polynomial corresponding to the discriminant x",
   "random()=random integer between 0 and 2^31-1",
